summaryrefslogtreecommitdiff
path: root/nuttx/configs/lincoln60/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/lincoln60/src/up_buttons.c')
-rw-r--r--nuttx/configs/lincoln60/src/up_buttons.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/configs/lincoln60/src/up_buttons.c b/nuttx/configs/lincoln60/src/up_buttons.c
index 53c9db4e9..d50a9e59a 100644
--- a/nuttx/configs/lincoln60/src/up_buttons.c
+++ b/nuttx/configs/lincoln60/src/up_buttons.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * configs/lincoln60/src/up_buttons.c
+ * configs/lincoln60/src/board_buttons.c
*
* Copyright (C) 2012-2013 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -98,7 +98,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
@@ -117,14 +117,14 @@ void board_button_initialize(void)
}
/****************************************************************************
- * Name: up_buttons
+ * Name: board_buttons
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons.
*
* up_buttons() may be called at any time to harvest the state of every
* button. The state of the buttons is returned as a bitset with one
* bit corresponding to each button: If the bit is set, then the button
* is pressed. See the BOARD_BUTTON_*_BIT and BOARD_JOYSTICK_*_BIT
@@ -132,7 +132,7 @@ void board_button_initialize(void)
*
****************************************************************************/
-uint8_t up_buttons(void)
+uint8_t board_buttons(void)
{
uint8_t ret = 0;
int i;
@@ -98,7 +98,7 @@ static uint8_t g_buttonirq[BOARD_NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_buttons() may be called to collect the current state of all
+ * that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -117,14 +117,14 @@ void board_button_initialize(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_buttons() may be called to collect the current state of all
+ * that, board_buttons() may be called to collect the current state of all
* buttons.
*
@@ -117,14 +117,14 @@ void board_button_initialize(void)
* buttons.
*
- * up_buttons() may be called at any time to harvest the state of every
+ * board_buttons() may be called at any time to harvest the state of every
* button. The state of the buttons is returned as a bitset with one
* bit corresponding to each button: If the bit is set, then the button